gapipy package
==============

Subpackages
-----------

.. toctree::

    gapipy.models
    gapipy.resources

Submodules
----------

gapipy.cache module
-------------------

.. automodule:: gapipy.cache
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.client module
--------------------

.. automodule:: gapipy.client
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.query module
-------------------

.. automodule:: gapipy.query
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.request module
---------------------

.. automodule:: gapipy.request
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.utils module
-------------------

.. automodule:: gapipy.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: gapipy
    :members:
    :undoc-members:
    :show-inheritance:
